Enum TIPFeeAMMEvent
pub enum TIPFeeAMMEvent {
Mint(Mint),
Burn(Burn),
RebalanceSwap(RebalanceSwap),
}Expand description
Container for all the ITIPFeeAMM events.
Variants
Implementations
impl ITIPFeeAMMEvents
impl ITIPFeeAMMEvents
pub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
pub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
pub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
pub fn signature_by_selector(selector: [u8; 32]) -> Option<&'static str>
pub fn signature_by_selector(selector: [u8; 32]) -> Option<&'static str>
Returns the signature for the given selector, if known.
pub fn name_by_selector(selector: [u8; 32]) -> Option<&'static str>
pub fn name_by_selector(selector: [u8; 32]) -> Option<&'static str>
Returns the enum variant name for the given selector, if known.
impl ITIPFeeAMMEvents
impl ITIPFeeAMMEvents
pub fn mint(
sender: Address,
to: Address,
user_token: Address,
validator_token: Address,
amount_validator_token: Uint<256, 4>,
liquidity: Uint<256, 4>,
) -> ITIPFeeAMMEvents
pub fn mint( sender: Address, to: Address, user_token: Address, validator_token: Address, amount_validator_token: Uint<256, 4>, liquidity: Uint<256, 4>, ) -> ITIPFeeAMMEvents
Creates a Mint event.
event Mint(address,address,address,address,uint256,uint256)pub fn burn(
sender: Address,
user_token: Address,
validator_token: Address,
amount_user_token: Uint<256, 4>,
amount_validator_token: Uint<256, 4>,
liquidity: Uint<256, 4>,
to: Address,
) -> ITIPFeeAMMEvents
pub fn burn( sender: Address, user_token: Address, validator_token: Address, amount_user_token: Uint<256, 4>, amount_validator_token: Uint<256, 4>, liquidity: Uint<256, 4>, to: Address, ) -> ITIPFeeAMMEvents
Creates a Burn event.
event Burn(address,address,address,uint256,uint256,uint256,address)pub fn rebalance_swap(
user_token: Address,
validator_token: Address,
swapper: Address,
amount_in: Uint<256, 4>,
amount_out: Uint<256, 4>,
) -> ITIPFeeAMMEvents
pub fn rebalance_swap( user_token: Address, validator_token: Address, swapper: Address, amount_in: Uint<256, 4>, amount_out: Uint<256, 4>, ) -> ITIPFeeAMMEvents
Creates a RebalanceSwap event.
event RebalanceSwap(address,address,address,uint256,uint256)Trait Implementations
impl Clone for ITIPFeeAMMEvents
impl Clone for ITIPFeeAMMEvents
fn clone(&self) -> ITIPFeeAMMEvents
fn clone(&self) -> ITIPFeeAMMEvents
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Debug for ITIPFeeAMMEvents
impl Debug for ITIPFeeAMMEvents
impl<'de> Deserialize<'de> for ITIPFeeAMMEvents
impl<'de> Deserialize<'de> for ITIPFeeAMMEvents
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ITIPFeeAMMEvents, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ITIPFeeAMMEvents, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl Eq for ITIPFeeAMMEvents
impl IntoLogData for ITIPFeeAMMEvents
impl IntoLogData for ITIPFeeAMMEvents
fn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.fn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.impl PartialEq for ITIPFeeAMMEvents
impl PartialEq for ITIPFeeAMMEvents
fn eq(&self, other: &ITIPFeeAMMEvents) -> bool
fn eq(&self, other: &ITIPFeeAMMEvents) -> bool
self and other values to be equal, and is used by ==.impl Serialize for ITIPFeeAMMEvents
impl Serialize for ITIPFeeAMMEvents
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl SolEventInterface for ITIPFeeAMMEvents
impl SolEventInterface for ITIPFeeAMMEvents
fn decode_raw_log(
topics: &[FixedBytes<32>],
data: &[u8],
) -> Result<ITIPFeeAMMEvents, Error>
fn decode_raw_log( topics: &[FixedBytes<32>], data: &[u8], ) -> Result<ITIPFeeAMMEvents, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
impl StructuralPartialEq for ITIPFeeAMMEvents